Module config

Module config 

Configuration options for how to compress and encrypt databases

Structs

DatabaseConfig
Configuration of how a database should be stored
VariantDictionary
A dictionary of key-value pairs, with typed values

Enums

CompressionConfig
Choices of compression algorithm
CompressionConfigError
Errors with the configuration of the compression algorithm
DatabaseVersion
Supported KDB database versions, with the associated minor version.
InnerCipherConfig
Choices for encrypting protected values inside of databases
InnerCipherConfigError
Errors with the configuration of the inner encryption
KdfConfig
Choices for Key Derivation Functions (KDFs)
KdfConfigError
Errors with the configuration of the Key Derivation Function
OuterCipherConfig
Choices for outer encryption
OuterCipherConfigError
Errors with the configuration of the outer encryption
VariantDictionaryValue
A value in a VariantDictionary, which can be one of several types