#[non_exhaustive]pub enum DatabaseOpenError {
Io(Error),
UnexpectedEof,
VersionParse(DatabaseVersionParseError),
UnsupportedVersion,
Key(DatabaseKeyError),
Cryptography(CryptographyError),
Format(DatabaseFormatError),
}Expand description
Errors that can occur when opening a database
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Io(Error)
I/O errors that can occur while reading the database from the source
UnexpectedEof
An unexpected end of file was encountered while reading the database
VersionParse(DatabaseVersionParseError)
Errors related to parsing the database version from the file header
UnsupportedVersion
Attempted to open a database with an unsupported version
Key(DatabaseKeyError)
Errors related to the database key, such as incorrect keys
Cryptography(CryptographyError)
Errors related to decryption
Format(DatabaseFormatError)
Errors related to parsing the database format