#[non_exhaustive]pub enum MoveGroupError {
CannotMoveRoot,
NotFound(GroupId),
WouldCreateCycle,
}Expand description
Errors that can occur when moving a group to a new parent.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CannotMoveRoot
The root group cannot be moved
NotFound(GroupId)
The destination group was not found in the database.
This error can also occur if the destination group belongs to a different database.
WouldCreateCycle
Moving the group would create a cycle in the group hierarchy, which is not allowed.