AttachmentMut

Struct AttachmentMut 

pub struct AttachmentMut<'a> { /* private fields */ }
A mutable reference to an Attachment. Implements DerefMut to &mut Attachment

Implementations

Source

impl AttachmentMut<'_>

pub fn as_ref(&self) -> AttachmentRef<'_>

Get an immutable reference to this attachment.

pub fn edit(&mut self, f: impl FnOnce(&mut AttachmentMut<'_>)) -> &mut Self

Edit this attachment with a closure, which is passed a mutable reference to this attachment.

pub fn database_mut(&mut self) -> &mut Database

Get a mutable reference to the database that owns this attachment.

pub fn foreach_entry_mut<F>(&mut self, f: F, include_historical: bool)
where F: FnMut(EntryMut<'_>),

Get an iterator over the entries that reference this attachment, with mutable access.

If include_historical is false, only returns entries that currently reference this attachment. If include_historical is true, also returns old versions of entries that reference this attachment, even if they have been modified to no longer reference it.

pub fn remove(self)

Remove this attachment from the database, and all references to it

Methods from Deref<Target = Attachment>

pub fn id(&self) -> AttachmentId

Get the ID of this attachment.

Methods from Deref<Target = Value<Vec<u8>>>

pub fn is_protected(&self) -> bool

Returns true if the value is protected (either PBytes or PString)

pub fn get(&self) -> &T

Returns the value as a string slice