AttachmentRef

Struct AttachmentRef 

pub struct AttachmentRef<'a> { /* private fields */ }
An immutable reference to an Attachment. Implements Deref to &Attachment

Implementations

Source

impl AttachmentRef<'_>

pub fn database(&self) -> &Database

Get an immutable reference to the database that owns this attachment.

pub fn entries( &self, include_historical: bool, ) -> impl Iterator<Item = EntryRef<'_>>

Get an iterator over the entries that reference this attachment.

If include_historical is false, only returns entries that currently reference this attachment. If include_historical is true, also returns old versions of entries that reference this attachment, even if they have been modified to no longer reference it.

Methods from Deref<Target = Attachment>

pub fn id(&self) -> AttachmentId

Get the ID of this attachment.

Methods from Deref<Target = Value<Vec<u8>>>

pub fn is_protected(&self) -> bool

Returns true if the value is protected (either PBytes or PString)

pub fn get(&self) -> &T

Returns the value as a string slice