pub struct AutoType {
pub enabled: bool,
pub default_sequence: Option<String>,
pub data_transfer_obfuscation: DataTransferObfuscation,
pub associations: Vec<AutoTypeAssociation>,
}Expand description
An AutoType setting associated with an Entry
Fields
enabled: boolWhether AutoType is enabled for this entry
default_sequence: Option<String>Default AutoType sequence. This is used if no window associations match.
data_transfer_obfuscation: DataTransferObfuscationWhether an implementation MAY try to obfuscate Auto-Type key strokes to make it harder for key loggers to record the full sequence.
associations: Vec<AutoTypeAssociation>Window associations for this entry. The first association whose window matches the active window will be used.