Database

Struct Database 

pub struct Database {
    pub config: DatabaseConfig,
    pub meta: Meta,
    pub deleted_objects: HashMap<Uuid, Option<NaiveDateTime>>,
    /* private fields */
}
A decrypted KeePass database

Fields

config: DatabaseConfig

Configuration settings of the database such as encryption and compression algorithms

meta: Meta

Metadata of the KeePass database

deleted_objects: HashMap<Uuid, Option<NaiveDateTime>>

References to previously-deleted objects and their deletion times.

Implementations

Source

impl Database

pub fn open( source: &mut dyn Read, key: DatabaseKey, ) -> Result<Database, DatabaseOpenError>

Parse a database from a std::io::Read

pub fn parse( data: &[u8], key: DatabaseKey, ) -> Result<Database, DatabaseOpenError>

Parse a database from a byte slice

pub fn get_xml( source: &mut dyn Read, key: DatabaseKey, ) -> Result<Vec<u8>, DatabaseOpenError>

Helper function to load a database into its internal XML chunks

pub fn get_version( source: &mut dyn Read, ) -> Result<DatabaseVersion, DatabaseOpenError>

Get the version of a database without decrypting it

Source

impl Database

pub fn new() -> Self

Create a new database with a single root group and no entries, groups, or attachments.

The root group will be assigned a new random UUID.

pub fn with_config(config: DatabaseConfig) -> Self

Create a new database with the given configuration and a single root group.

The root group will be assigned a new random UUID.

pub fn new_with_root_id(root_id: GroupId) -> Self

Create a new database with the given group UUID

pub fn root(&self) -> GroupRef<'_>

Get an immutable reference to the root group of the database.

pub fn root_mut(&mut self) -> GroupMut<'_>

Get a mutable reference to the root group of the database.

pub fn recycle_bin(&self) -> Option<GroupRef<'_>>

Get an immutable reference to the recycle bin group, if it exists

pub fn recycle_bin_mut(&mut self) -> Option<GroupMut<'_>>

Get a mutable reference to the recycle bin group, if it exists

pub fn num_attachments(&self) -> usize

Get the number of attachments in the database

pub fn num_custom_icons(&self) -> usize

Get the number of custom icons in the database

pub fn num_entries(&self) -> usize

Get the number of entries in the database

pub fn num_groups(&self) -> usize

Get the number of groups in the database, including the root group and the recycle bin (if it exists)

pub fn iter_all_attachments( &self, ) -> impl Iterator<Item = AttachmentRef<'_>> + '_

Iterate over all attachments with immutable access.

pub fn foreach_attachment_mut<F>(&mut self, f: F)
where F: FnMut(AttachmentMut<'_>),

Iterate over all attachments with mutable access. The provided closure is called for each AttachmentMut and borrows are limited to the closure body.

pub fn iter_all_entries(&self) -> impl Iterator<Item = EntryRef<'_>> + '_

Iterate over all entries with immutable access.

pub fn foreach_entry_mut<F>(&mut self, f: F)
where F: FnMut(EntryMut<'_>),

Iterate over all entries with mutable access. The provided closure is called for each EntryMut and borrows are limited to the closure body.

pub fn iter_all_custom_icons( &self, ) -> impl Iterator<Item = CustomIconRef<'_>> + '_

Iterate over all custom icons with immutable access.

pub fn foreach_custom_icon_mut<F>(&mut self, f: F)
where F: FnMut(CustomIconMut<'_>),

Iterate over all custom icons with mutable access. The provided closure is called for each CustomIconMut and borrows are limited to the closure body.

pub fn iter_all_groups(&self) -> impl Iterator<Item = GroupRef<'_>> + '_

Iterate over all groups with immutable access. This includes the root group and the recycle bin (if it exists).

pub fn foreach_group_mut<F>(&mut self, f: F)
where F: FnMut(GroupMut<'_>),

Iterate over all groups with mutable access. The provided closure is called for each GroupMut and borrows are limited to the closure body.

pub fn attachment(&self, id: AttachmentId) -> Option<AttachmentRef<'_>>

Get an immutable reference to the attachment with the given ID, if it exists

pub fn attachment_mut(&mut self, id: AttachmentId) -> Option<AttachmentMut<'_>>

Get a mutable reference to the attachment with the given ID, if it exists

pub fn custom_icon(&self, id: CustomIconId) -> Option<CustomIconRef<'_>>

Get an immutable reference to the custom icon with the given ID, if it exists

pub fn custom_icon_mut(&mut self, id: CustomIconId) -> Option<CustomIconMut<'_>>

Get a mutable reference to the custom icon with the given ID, if it exists

pub fn entry(&self, id: EntryId) -> Option<EntryRef<'_>>

Get an immutable reference to the entry with the given ID, if it exists

pub fn entry_mut(&mut self, id: EntryId) -> Option<EntryMut<'_>>

Get a mutable reference to the entry with the given ID, if it exists

pub fn group(&self, id: GroupId) -> Option<GroupRef<'_>>

Get an immutable reference to the group with the given ID, if it exists

pub fn group_mut(&mut self, id: GroupId) -> Option<GroupMut<'_>>

Get a mutable reference to the group with the given ID, if it exists