EntryRef

Struct EntryRef 

pub struct EntryRef<'a> { /* private fields */ }
An immutable reference to an Entry. Implements Deref to &Entry.

Implementations

Source

impl EntryRef<'_>

pub fn parent(&self) -> GroupRef<'_>

Get a reference to the parent group of this entry.

pub fn previous_parent(&self) -> Option<GroupRef<'_>>

Get a reference to the previous parent group, if any

pub fn historical(&self, index: usize) -> Option<EntryRef<'_>>

Gets an EntryRef to a historical version of the Entry, if it exists

pub fn database(&self) -> &Database

Get a reference to the underlying database

pub fn attachment(&self, id: AttachmentId) -> Option<AttachmentRef<'_>>

Get a reference to an attachment by id, if it exists.

pub fn attachment_by_name(&self, name: &str) -> Option<AttachmentRef<'_>>

Get a reference to an attachment by name, if it exists.

pub fn attachments(&self) -> impl Iterator<Item = AttachmentRef<'_>>

Get an iterator over the attachments of this entry.

pub fn attachments_named( &self, ) -> impl Iterator<Item = (&str, AttachmentRef<'_>)>

Get an iterator over the (name, attachment) pairs of this entry.

Useful when callers need both the attachment’s filename (the key under which it is stored on the entry) and its data, since AttachmentRef itself does not expose the per-entry name.

pub fn custom_icon(&self) -> Option<CustomIconRef<'_>>

Get the custom icon of this entry, if it exists and is a custom icon.

Methods from Deref<Target = Entry>

pub fn id(&self) -> EntryId

Get the unique identifier for the Entry

pub fn icon(&self) -> Option<&Icon>

Get the icon of this entry, if it exists

pub fn get(&self, key: &str) -> Option<&str>

Get a field by name, taking care of unprotecting Protected values automatically

pub fn get_raw_otp_value(&self) -> Option<&str>

Convenience method for getting the raw value of the ‘otp’ field

pub fn get_title(&self) -> Option<&str>

Convenience method for getting the value of the ‘Title’ field

pub fn get_username(&self) -> Option<&str>

Convenience method for getting the value of the ‘UserName’ field

pub fn get_password(&self) -> Option<&str>

Convenience method for getting the value of the ‘Password’ field

pub fn get_url(&self) -> Option<&str>

Convenience method for getting the value of the ‘URL’ field