Group

Struct Group 

pub struct Group {
    pub name: String,
    pub notes: Option<String>,
    pub tags: Vec<String>,
    pub times: Times,
    pub custom_data: HashMap<String, CustomDataItem>,
    pub is_expanded: bool,
    pub default_autotype_sequence: Option<String>,
    pub enable_autotype: Option<bool>,
    pub enable_searching: Option<bool>,
    /* private fields */
}
A database group with child groups and entries

Fields

name: String

The name of the group

notes: Option<String>

Notes for the group

tags: Vec<String>

The list of tags for this group

times: Times

The list of time fields for this group

custom_data: HashMap<String, CustomDataItem>

Custom Data

is_expanded: bool

Whether the group is expanded in the user interface

default_autotype_sequence: Option<String>

Default autotype sequence

enable_autotype: Option<bool>

Whether autotype is enabled

enable_searching: Option<bool>

Whether searching is enabled

Implementations

Source

impl Group

pub fn id(&self) -> GroupId

Get the unique identifier for this group

pub fn group_ids(&self) -> impl Iterator<Item = GroupId> + '_

Get an iterator over the IDs of all contained groups

pub fn entry_ids(&self) -> impl Iterator<Item = EntryId> + '_

Get an iterator over the IDs of all contained entries

pub fn icon(&self) -> Option<&Icon>

Get a reference to the icon of this group, if any