pub struct GroupRef<'a> { /* private fields */ }Implementations
Sourceimpl GroupRef<'_>
impl GroupRef<'_>
Sourcepub fn groups(&self) -> impl Iterator<Item = GroupRef<'_>> + '_
pub fn groups(&self) -> impl Iterator<Item = GroupRef<'_>> + '_
Get an iterator over all contained groups
Sourcepub fn entries(&self) -> impl Iterator<Item = EntryRef<'_>> + '_
pub fn entries(&self) -> impl Iterator<Item = EntryRef<'_>> + '_
Get an iterator over all contained entries
Sourcepub fn group_by_name(&self, name: &str) -> Option<GroupRef<'_>>
pub fn group_by_name(&self, name: &str) -> Option<GroupRef<'_>>
Find a contained group by name, case-insensitively.
Sourcepub fn entry_by_name(&self, title: &str) -> Option<EntryRef<'_>>
pub fn entry_by_name(&self, title: &str) -> Option<EntryRef<'_>>
Find a contained entry by title, case-insensitively.
Sourcepub fn group_by_path(&self, path: &[&str]) -> Option<GroupRef<'_>>
pub fn group_by_path(&self, path: &[&str]) -> Option<GroupRef<'_>>
Find a contained group by a path of names, case-insensitively.
Sourcepub fn previous_parent(&self) -> Option<GroupRef<'_>>
pub fn previous_parent(&self) -> Option<GroupRef<'_>>
Get a reference to the previous parent group, if any
Sourcepub fn custom_icon(&self) -> Option<CustomIconRef<'_>>
pub fn custom_icon(&self) -> Option<CustomIconRef<'_>>
Get a reference to the custom icon of this group, if it has one and it is a custom icon
Methods from Deref<Target = Group>