pub struct GroupTrack<'a> { /* private fields */ }Expand description
A variant of GroupMut that tracks changes to the group, such as deletions and moves, and updates the location changed time when the group is moved.
Implementations
Sourceimpl GroupTrack<'_>
impl GroupTrack<'_>
Sourcepub fn move_to(&mut self, new_parent_id: GroupId) -> Result<(), MoveGroupError>
pub fn move_to(&mut self, new_parent_id: GroupId) -> Result<(), MoveGroupError>
Move this group to a new parent group, updating the location changed time.
Sourcepub fn remove(self) -> Result<(), CannotDeleteRootError>
pub fn remove(self) -> Result<(), CannotDeleteRootError>
Deletes this group and all its child groups and entries from the database, adding them to the deleted entries and groups sets.
Sourcepub fn edit(&mut self, f: impl FnOnce(&mut GroupTrack<'_>)) -> &mut Self
pub fn edit(&mut self, f: impl FnOnce(&mut GroupTrack<'_>)) -> &mut Self
Convenience method to edit the group in a closure, updating the last modification time.
Methods from Deref<Target = Group>