pub struct Meta {Show 24 fields
pub generator: Option<String>,
pub database_name: Option<String>,
pub database_name_changed: Option<NaiveDateTime>,
pub database_description: Option<String>,
pub database_description_changed: Option<NaiveDateTime>,
pub default_username: Option<String>,
pub default_username_changed: Option<NaiveDateTime>,
pub maintenance_history_days: Option<usize>,
pub color: Option<Color>,
pub master_key_changed: Option<NaiveDateTime>,
pub master_key_change_rec: Option<isize>,
pub master_key_change_force: Option<isize>,
pub memory_protection: Option<MemoryProtection>,
pub recyclebin_enabled: Option<bool>,
pub recyclebin_uuid: Option<Uuid>,
pub recyclebin_changed: Option<NaiveDateTime>,
pub entry_templates_group: Option<Uuid>,
pub entry_templates_group_changed: Option<NaiveDateTime>,
pub last_selected_group: Option<Uuid>,
pub last_top_visible_group: Option<Uuid>,
pub history_max_items: Option<isize>,
pub history_max_size: Option<isize>,
pub settings_changed: Option<NaiveDateTime>,
pub custom_data: HashMap<String, CustomDataItem>,
}Expand description
Database metadata
Fields
generator: Option<String>the program that generated the database file.
database_name: Option<String>name of the database
database_name_changed: Option<NaiveDateTime>time the database name was last changed
database_description: Option<String>description of the database
database_description_changed: Option<NaiveDateTime>time the database description was last changed
default_username: Option<String>default username
default_username_changed: Option<NaiveDateTime>time the default username was last changed
maintenance_history_days: Option<usize>number of days of maintenance history to keep
color: Option<Color>color code for the database
master_key_changed: Option<NaiveDateTime>time the master key was last changed
master_key_change_rec: Option<isize>Number of days until a change of the master key is recommended. -1 means never.
master_key_change_force: Option<isize>Number of days until a change of the master key is forced. -1 means never.
memory_protection: Option<MemoryProtection>memory protection settings
recyclebin_enabled: Option<bool>whether the recycle bin is enabled
recyclebin_uuid: Option<Uuid>A UUID for the recycle bin group
recyclebin_changed: Option<NaiveDateTime>last time the recycle bin was changed
entry_templates_group: Option<Uuid>UUID of the group containing entry templates
entry_templates_group_changed: Option<NaiveDateTime>last time the group containing entry templates was changed
last_selected_group: Option<Uuid>UUID of the last selected group
last_top_visible_group: Option<Uuid>UUID of the last top-visible group
history_max_items: Option<isize>Maximum number of items of history to keep
history_max_size: Option<isize>Maximum size of the history to keep
settings_changed: Option<NaiveDateTime>Last time the settings were changed
custom_data: HashMap<String, CustomDataItem>Additional custom data fields