Module error

Module error 

Error types that this crate can return

Re-exports

pub use crate::config::CompressionConfigError;
pub use crate::config::InnerCipherConfigError;
pub use crate::config::KdfConfigError;
pub use crate::config::OuterCipherConfigError;
pub use crate::db::CustomIconNotFoundError;
pub use crate::db::DatabaseFormatError;
pub use crate::db::DatabaseOpenError;
pub use crate::db::DestinationGroupNotFoundError;
pub use crate::db::DuplicateEntryIdError;
pub use crate::db::DuplicateGroupIdError;
pub use crate::db::MoveGroupError;
pub use crate::db::ParseColorError;

Enums

BlockStreamError
Errors reading from the HMAC block stream
CryptographyError
Errors that can occur during cryptographic operations
DatabaseKeyError
Errors that can occur when working with database keys
DatabaseVersionParseError
Errors that can occur during parsing of the database version from a KDBX file
KdbOpenError
Errors that can occur when opening a KeePass 1 database
Kdbx3OpenError
Errors related to opening a KDBX3 database
Kdbx3OuterHeaderError
Errors related to parsing the outer header of a KDBX3 database
Kdbx4InnerHeaderError
Errors that can occur while parsing the KDBX4 inner header
Kdbx4OpenError
Errors that can occur while parsing a KDBX4 database
Kdbx4OuterHeaderError
Errors that can occur while parsing the KDBX4 outer header
ParseXmlError
Errors that can occur during parsing of the inner XML database of a KDBX file
ParseXmlKeyFileError
Errors that can occur when parsing an XML keyfile
VariantDictionaryError
Errors while parsing a VariantDictionary