#[non_exhaustive]pub enum BlockStreamError {
BlockHashMismatch {
block_index: u64,
},
Eof,
}Expand description
Errors reading from the HMAC block stream
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BlockHashMismatch
The HMAC of a block did not match the expected value, indicating that the data may be corrupted or tampered with.
Eof
The end of the file was reached unexpectedly while reading a block, indicating that the data may be incomplete or corrupted.