#[non_exhaustive]pub enum DatabaseVersionParseError {
UnexpectedEof,
InvalidKDBXIdentifier,
InvalidKDBXVersion {
version: u32,
file_major_version: u32,
file_minor_version: u32,
},
}Expand description
Errors that can occur during parsing of the database version from a KDBX file
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
UnexpectedEof
Encountered an unexpected end of file while reading the database version header, which should be at least 12 bytes long.
InvalidKDBXIdentifier
The first 4 bytes of a KDBX file did not match the expected KDBX identifier
InvalidKDBXVersion
The version information in the KDBX file did not match any supported database versions