#[non_exhaustive]pub enum Kdbx3OpenError {
OuterHeader(Kdbx3OuterHeaderError),
BlockHashMismatch(usize),
Xml(ParseXmlError),
}Expand description
Errors related to opening a KDBX3 database
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
OuterHeader(Kdbx3OuterHeaderError)
Errors related to parsing the outer header of the KDBX3 database
BlockHashMismatch(usize)
A data block has a hash that does not match the expected hash, indicating possible corruption
Xml(ParseXmlError)
Errors related to parsing the inner XML database of the KDBX3 file