#[non_exhaustive]pub enum Kdbx3OuterHeaderError {
InnerCipher(InnerCipherConfigError),
OuterCipher(OuterCipherConfigError),
Compression(CompressionConfigError),
InvalidOuterHeaderEntry(u8),
IncompleteOuterHeader(&'static str),
UnexpectedEof,
}Expand description
Errors related to parsing the outer header of a KDBX3 database
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InnerCipher(InnerCipherConfigError)
Errors related to parsing the inner cipher configuration
OuterCipher(OuterCipherConfigError)
Errors related to parsing the outer cipher configuration
Compression(CompressionConfigError)
Errors related to parsing the compression configuration
InvalidOuterHeaderEntry(u8)
An outer header entry has an invalid type identifier
IncompleteOuterHeader(&'static str)
The outer header is missing a required entry
UnexpectedEof
Encountered an unexpected end of file while reading the outer header