#[non_exhaustive]pub enum Kdbx4OpenError {
Xml(ParseXmlError),
OuterHeader(Kdbx4OuterHeaderError),
InnerHeader(Kdbx4InnerHeaderError),
HeaderHashMismatch,
BlockStream(BlockStreamError),
}Expand description
Errors that can occur while parsing a KDBX4 database
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Xml(ParseXmlError)
Errors related to XML parsing of the inner database
OuterHeader(Kdbx4OuterHeaderError)
Errors related to parsing the outer header of the KDBX4 file
InnerHeader(Kdbx4InnerHeaderError)
Errors related to parsing the inner header of the KDBX4 file
HeaderHashMismatch
The SHA256 hash of the outer header did not match the expected value, indicating that the header may be corrupted or tampered with.
BlockStream(BlockStreamError)
Errors related to the HMAC-verified block stream of the KDBX4 file