Kdbx4OuterHeaderError

Enum Kdbx4OuterHeaderError 

#[non_exhaustive]
pub enum Kdbx4OuterHeaderError { UnexpectedEof, OuterCipherConfig(OuterCipherConfigError), CompressionConfig(CompressionConfigError), ParseKdfConfig(VariantDictionaryError), ParseCustomData(VariantDictionaryError), KdfConfig(KdfConfigError), InvalidEntry(u8), Incomplete(&'static str), }
Errors that can occur while parsing the KDBX4 outer header

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


UnexpectedEof

The file ended unexpectedly while parsing the outer header



OuterCipherConfig(OuterCipherConfigError)

Errors related to the outer cipher configuration



CompressionConfig(CompressionConfigError)

Errors related to the compression configuration



ParseKdfConfig(VariantDictionaryError)

Errors related to parsing the key derivation function configuration



ParseCustomData(VariantDictionaryError)

Errors related to parsing the public custom data



KdfConfig(KdfConfigError)

Errors related to the key derivation function configuration



InvalidEntry(u8)

The outer header contains an entry with an unrecognized or invalid entry type identifier



Incomplete(&'static str)

The outer header is missing a required field