#[non_exhaustive]pub enum ParseXmlError {
Xml(DeError),
Unprotect(UnprotectError),
}Expand description
Errors that can occur during parsing of the inner XML database of a KDBX file
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Xml(DeError)
Errors related to XML deserialization or serialization.
Unprotect(UnprotectError)
Errors related to unprotecting entries, such as decryption failures or unsupported encryption methods.