#[non_exhaustive]pub enum ParseXmlKeyFileError {
EmptyKey,
Encoding(EncodingError),
Xml(Error),
}Expand description
Errors that can occur when parsing an XML keyfile
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
EmptyKey
No key data element was found in the XML keyfile
Encoding(EncodingError)
A tag in the XML keyfile contains text that cannot be decoded as UTF-8
Xml(Error)
An error occurred while reading the XML keyfile