#[non_exhaustive]pub enum VariantDictionaryError {
InvalidVersion {
version: u16,
},
InvalidValueType {
value_type: u8,
},
MissingKey {
key: String,
},
Mistyped {
key: String,
},
NotTerminated,
UnexpectedEof,
}Expand description
Errors while parsing a VariantDictionary
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
InvalidVersion
An invalid VariantDictionary version was encountered.
InvalidValueType
An invalid value type was encountered while parsing a VariantDictionary.
MissingKey
A required key was missing from the VariantDictionary.
Mistyped
A value was found for the specified key, but it was of an unexpected type.
NotTerminated
The VariantDictionary did not end with a null byte (0x00) as expected.
UnexpectedEof
An unexpected end of file was encountered while parsing the VariantDictionary