pub struct AttachmentRef<'a> { /* private fields */ }Expand description
An immutable reference to an Attachment. Implements Deref to &Attachment
Implementations
Sourceimpl AttachmentRef<'_>
impl AttachmentRef<'_>
Sourcepub fn database(&self) -> &Database
pub fn database(&self) -> &Database
Get an immutable reference to the database that owns this attachment.
Sourcepub fn entries(
&self,
include_historical: bool,
) -> impl Iterator<Item = EntryRef<'_>>
pub fn entries( &self, include_historical: bool, ) -> impl Iterator<Item = EntryRef<'_>>
Get an iterator over the entries that reference this attachment.
If include_historical is false, only returns entries that currently reference this
attachment. If include_historical is true, also returns old versions of entries that
reference this attachment, even if they have been modified to no longer reference it.
Methods from Deref<Target = Attachment>
Sourcepub fn id(&self) -> AttachmentId
pub fn id(&self) -> AttachmentId
Get the ID of this attachment.