Entry

Struct Entry 

pub struct Entry {
    pub fields: HashMap<String, Value<String>>,
    pub autotype: Option<AutoType>,
    pub tags: Vec<String>,
    pub times: Times,
    pub custom_data: HashMap<String, CustomDataItem>,
    pub foreground_color: Option<Color>,
    pub background_color: Option<Color>,
    pub override_url: Option<String>,
    pub quality_check: bool,
    pub history: Option<History>,
    /* private fields */
}
A database entry containing several key-value fields.

Fields

fields: HashMap<String, Value<String>>

the key-value fields of this entry, such as username and password.

Common field names are available in crate::db::fields.

autotype: Option<AutoType>

AutoType settings for this entry

tags: Vec<String>

tags associated with this entry

times: Times

timestamps for this entry

custom_data: HashMap<String, CustomDataItem>

custom data items associated with this entry

foreground_color: Option<Color>

foreground color for this entry

background_color: Option<Color>

background color for this entry

override_url: Option<String>

URL override for this entry

quality_check: bool

whether to enable password quality check for this entry

history: Option<History>

history of this entry

Implementations

Source

impl Entry

pub fn id(&self) -> EntryId

Get the unique identifier for the Entry

pub fn icon(&self) -> Option<&Icon>

Get the icon of this entry, if it exists

pub fn get(&self, key: &str) -> Option<&str>

Get a field by name, taking care of unprotecting Protected values automatically

pub fn set(&mut self, key: impl Into<String>, value: Value<String>)

Set a field’s value by name

pub fn set_unprotected( &mut self, key: impl Into<String>, value: impl Into<String>, )

Set a field’s unprotected value by name

pub fn set_protected( &mut self, key: impl Into<String>, value: impl Into<String>, )

Set a field’s protected value by name

pub fn get_raw_otp_value(&self) -> Option<&str>

Convenience method for getting the raw value of the ‘otp’ field

pub fn get_title(&self) -> Option<&str>

Convenience method for getting the value of the ‘Title’ field

pub fn get_username(&self) -> Option<&str>

Convenience method for getting the value of the ‘UserName’ field

pub fn get_password(&self) -> Option<&str>

Convenience method for getting the value of the ‘Password’ field

pub fn get_url(&self) -> Option<&str>

Convenience method for getting the value of the ‘URL’ field