pub struct EntryRef<'a> { /* private fields */ }Implementations
Sourceimpl EntryRef<'_>
impl EntryRef<'_>
Sourcepub fn previous_parent(&self) -> Option<GroupRef<'_>>
pub fn previous_parent(&self) -> Option<GroupRef<'_>>
Get a reference to the previous parent group, if any
Sourcepub fn historical(&self, index: usize) -> Option<EntryRef<'_>>
pub fn historical(&self, index: usize) -> Option<EntryRef<'_>>
Sourcepub fn attachment(&self, id: AttachmentId) -> Option<AttachmentRef<'_>>
pub fn attachment(&self, id: AttachmentId) -> Option<AttachmentRef<'_>>
Get a reference to an attachment by id, if it exists.
Sourcepub fn attachment_by_name(&self, name: &str) -> Option<AttachmentRef<'_>>
pub fn attachment_by_name(&self, name: &str) -> Option<AttachmentRef<'_>>
Get a reference to an attachment by name, if it exists.
Sourcepub fn attachments(&self) -> impl Iterator<Item = AttachmentRef<'_>>
pub fn attachments(&self) -> impl Iterator<Item = AttachmentRef<'_>>
Get an iterator over the attachments of this entry.
Sourcepub fn attachments_named(
&self,
) -> impl Iterator<Item = (&str, AttachmentRef<'_>)>
pub fn attachments_named( &self, ) -> impl Iterator<Item = (&str, AttachmentRef<'_>)>
Get an iterator over the (name, attachment) pairs of this entry.
Useful when callers need both the attachment’s filename (the key under
which it is stored on the entry) and its data, since AttachmentRef
itself does not expose the per-entry name.
Sourcepub fn custom_icon(&self) -> Option<CustomIconRef<'_>>
pub fn custom_icon(&self) -> Option<CustomIconRef<'_>>
Get the custom icon of this entry, if it exists and is a custom icon.
Methods from Deref<Target = Entry>
Sourcepub fn get(&self, key: &str) -> Option<&str>
pub fn get(&self, key: &str) -> Option<&str>
Get a field by name, taking care of unprotecting Protected values automatically
Sourcepub fn get_raw_otp_value(&self) -> Option<&str>
pub fn get_raw_otp_value(&self) -> Option<&str>
Convenience method for getting the raw value of the ‘otp’ field
Sourcepub fn get_title(&self) -> Option<&str>
pub fn get_title(&self) -> Option<&str>
Convenience method for getting the value of the ‘Title’ field
Sourcepub fn get_username(&self) -> Option<&str>
pub fn get_username(&self) -> Option<&str>
Convenience method for getting the value of the ‘UserName’ field
Sourcepub fn get_password(&self) -> Option<&str>
pub fn get_password(&self) -> Option<&str>
Convenience method for getting the value of the ‘Password’ field