EntryTrack

Struct EntryTrack 

pub struct EntryTrack<'a> { /* private fields */ }
A variant of EntryMut that will persist the history of the entry when dropped.

Implementations

Source

impl EntryTrack<'_>

pub fn as_mut(&mut self) -> EntryMut<'_>

Turn this tracked entry into a normal mutable reference to the entry

pub fn move_to( &mut self, group_id: GroupId, ) -> Result<(), DestinationGroupNotFoundError>

Move this entry to another group, tracking the change in history.

pub fn remove(self)

Remove this entry from the database, tracking the change in history.

pub fn edit(&mut self, f: impl FnOnce(&mut EntryTrack<'_>)) -> &mut Self

Convenience method to edit the entry in a closure, tracking changes.

pub fn set(&mut self, key: impl Into<String>, value: Value<String>)

Set a field value, tracking changes. See crate::db::fields for common field names.

pub fn set_protected( &mut self, key: impl Into<String>, value: impl Into<String>, )

Set a protected field value, tracking changes. See crate::db::fields for common field names.

pub fn set_unprotected( &mut self, key: impl Into<String>, value: impl Into<String>, )

Set an unprotected field value, tracking changes. See crate::db::fields for common field names.

pub fn add_attachment( &mut self, name: impl Into<String>, data: Value<Vec<u8>>, ) -> AttachmentMut<'_>

Add an attachment, tracking changes.

pub fn set_icon_none(&mut self)

Remove the entry’s icon, tracking changes.

pub fn set_icon_builtin(&mut self, icon_id: usize)

Set a built-in icon for this entry by its ID, tracking changes.

pub fn set_icon_custom( &mut self, custom_icon_id: CustomIconId, ) -> Result<(), CustomIconNotFoundError>

Set a custom icon for this entry by its ID, tracking changes.

pub fn set_icon_custom_new(&mut self, data: Vec<u8>) -> CustomIconMut<'_>

Set a custom icon for this entry by providing the raw data, tracking changes. Returns a mutable reference to the newly created custom icon.

Methods from Deref<Target = Entry>

pub fn id(&self) -> EntryId

Get the unique identifier for the Entry

pub fn icon(&self) -> Option<&Icon>

Get the icon of this entry, if it exists

pub fn get(&self, key: &str) -> Option<&str>

Get a field by name, taking care of unprotecting Protected values automatically

pub fn set(&mut self, key: impl Into<String>, value: Value<String>)

Set a field’s value by name

pub fn set_unprotected( &mut self, key: impl Into<String>, value: impl Into<String>, )

Set a field’s unprotected value by name

pub fn set_protected( &mut self, key: impl Into<String>, value: impl Into<String>, )

Set a field’s protected value by name

pub fn get_raw_otp_value(&self) -> Option<&str>

Convenience method for getting the raw value of the ‘otp’ field

pub fn get_title(&self) -> Option<&str>

Convenience method for getting the value of the ‘Title’ field

pub fn get_username(&self) -> Option<&str>

Convenience method for getting the value of the ‘UserName’ field

pub fn get_password(&self) -> Option<&str>

Convenience method for getting the value of the ‘Password’ field

pub fn get_url(&self) -> Option<&str>

Convenience method for getting the value of the ‘URL’ field