GroupTrack

Struct GroupTrack 

pub struct GroupTrack<'a> { /* private fields */ }
A variant of GroupMut that tracks changes to the group, such as deletions and moves, and updates the location changed time when the group is moved.

Implementations

Source

impl GroupTrack<'_>

pub fn as_mut(&mut self) -> GroupMut<'_>

Turn the GroupTrack back into a regular GroupMut

pub fn move_to(&mut self, new_parent_id: GroupId) -> Result<(), MoveGroupError>

Move this group to a new parent group, updating the location changed time.

pub fn remove(self) -> Result<(), CannotDeleteRootError>

Deletes this group and all its child groups and entries from the database, adding them to the deleted entries and groups sets.

pub fn edit(&mut self, f: impl FnOnce(&mut GroupTrack<'_>)) -> &mut Self

Convenience method to edit the group in a closure, updating the last modification time.

Methods from Deref<Target = Group>

pub fn id(&self) -> GroupId

Get the unique identifier for this group

pub fn group_ids(&self) -> impl Iterator<Item = GroupId> + '_

Get an iterator over the IDs of all contained groups

pub fn entry_ids(&self) -> impl Iterator<Item = EntryId> + '_

Get an iterator over the IDs of all contained entries

pub fn icon(&self) -> Option<&Icon>

Get a reference to the icon of this group, if any