Error types that this crate can return
Re-exports
pub use crate::config::CompressionConfigError;pub use crate::config::InnerCipherConfigError;pub use crate::config::KdfConfigError;pub use crate::config::OuterCipherConfigError;pub use crate::db::CustomIconNotFoundError;pub use crate::db::DatabaseFormatError;pub use crate::db::DatabaseOpenError;pub use crate::db::DestinationGroupNotFoundError;pub use crate::db::DuplicateEntryIdError;pub use crate::db::DuplicateGroupIdError;pub use crate::db::MoveGroupError;pub use crate::db::ParseColorError;
Enums
- Block
Stream Error - Errors reading from the HMAC block stream
- Cryptography
Error - Errors that can occur during cryptographic operations
- Database
KeyError - Errors that can occur when working with database keys
- Database
Version Parse Error - Errors that can occur during parsing of the database version from a KDBX file
- KdbOpen
Error - Errors that can occur when opening a KeePass 1 database
- Kdbx3
Open Error - Errors related to opening a KDBX3 database
- Kdbx3
Outer Header Error - Errors related to parsing the outer header of a KDBX3 database
- Kdbx4
Inner Header Error - Errors that can occur while parsing the KDBX4 inner header
- Kdbx4
Open Error - Errors that can occur while parsing a KDBX4 database
- Kdbx4
Outer Header Error - Errors that can occur while parsing the KDBX4 outer header
- Parse
XmlError - Errors that can occur during parsing of the inner XML database of a KDBX file
- Parse
XmlKey File Error - Errors that can occur when parsing an XML keyfile
- Variant
Dictionary Error - Errors while parsing a VariantDictionary