[−][src]Struct keepass::Entry
A database entry containing several key-value fields.
Fields
fields: HashMap<String, Value>autotype: Option<AutoType>Implementations
impl<'a> Entry[src]
pub fn get(&'a self, key: &str) -> Option<&'a str>[src]
Get a field by name, taking care of unprotecting Protected values automatically
pub fn get_bytes(&'a self, key: &str) -> Option<&'a [u8]>[src]
Get a bytes field by name
pub fn get_title(&'a self) -> Option<&'a str>[src]
Convenience method for getting the value of the 'Title' field
pub fn get_username(&'a self) -> Option<&'a str>[src]
Convenience method for getting the value of the 'UserName' field
pub fn get_password(&'a self) -> Option<&'a str>[src]
Convenience method for getting the value of the 'Password' field